==> openjdk-13_13.0.7+5.orig.tar.xz: openjdk-13-13.0.7+5/test/langtools/jdk/javadoc/doclet/testHelpFile/TestHelpFile.java <==
/*
 * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * @test
 * @bug      7132631
 * @summary  Make sure that the help file is generated correctly.
 * @author   Bhavesh Patel
 * @library  ../../lib
 * @modules jdk.javadoc/jdk.javadoc.internal.tool
 * @build    javadoc.tester.*
 * @run main TestHelpFile
 */

import javadoc.tester.JavadocTester;

public class TestHelpFile extends JavadocTester {

    public static void main(String... args) throws Exception {
        TestHelpFile tester = new TestHelpFile();
        tester.runTests();
    }

    @Test
    public void test() {
        javadoc("-d", "out",
                "-sourcepath", testSrc,
                testSrc("TestHelpFile.java"));
        checkExit(Exit.OK);

        checkOutput("help-doc.html", true,
            "<a href=\"constant-values.html\">Constant Field Values</a>");
    }
}

==> openjdk-15_15.0.3+3.orig.tar.xz: openjdk-15-15.0.3+3/test/langtools/jdk/javadoc/doclet/testHelpFile/TestHelpFile.java <==
/*
 * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * @test
 * @bug      7132631 8241693
 * @summary  Make sure that the help file is generated correctly.
 * @library  ../../lib
 * @modules jdk.javadoc/jdk.javadoc.internal.tool
 * @build    javadoc.tester.*
 * @run main TestHelpFile
 */

import javadoc.tester.JavadocTester;

public class TestHelpFile extends JavadocTester {

    public static void main(String... args) throws Exception {
        TestHelpFile tester = new TestHelpFile();
        tester.runTests();
    }

    @Test
    public void test() {
        javadoc("-d", "out",
                "-sourcepath", testSrc,
                testSrc("TestHelpFile.java"));
        checkExit(Exit.OK);

        checkOutput("help-doc.html", true,
            """
                <a href="constant-values.html">Constant Field Values</a>""");

        // check a representative sample of the contents
        checkOrder("help-doc.html",
                """
                    </div>
                    <section class="help-section">
                    <h2>Package</h2>""",
                """
                    <ul class="help-section-list">
                    <li>Interfaces</li>
                    <li>Classes</li>
                    <li>Enums</li>""",
                """
                    </section>
                    <section class="help-section">
                    <h2>Class or Interface</h2>""",
                """
                    <ul class="help-section-list">
                    <li>Class Inheritance Diagram</li>
                    <li>Direct Subclasses</li>
                    """);
    }
}
